@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 Red Hat, Inc.
+ * Copyright (C) 2002,2003 Red Hat, Inc.
  *
  * This is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Library General Public License as published by
@@ -16,8 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: iso2022.c,v 1.17 2002/12/14 00:40:53 nalin Exp $"
-#include "config.h"
+#ident "$Id: iso2022.c,v 1.19 2003/01/18 17:54:29 nalin Exp $"
+#include "../config.h"
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
